@@ -1,10 +1,11 @@
 mod common;
 
+#[cfg(feature = "osrs")]
 mod osrs {
     use super::common;
     
     #[test]
-    fn load_blue_partyhat() -> rscache::Result<()> {
+    fn load_item_blue_partyhat() -> rscache::Result<()> {
         let cache = common::osrs::setup()?;
         let item_loader = common::osrs::load_items(&cache)?;
         
@@ -18,7 +19,7 @@ mod osrs {
     }
     
     #[test]
-    fn load_magic_logs() -> rscache::Result<()> {
+    fn load_item_magic_logs() -> rscache::Result<()> {
         let cache = common::osrs::setup()?;
         let item_loader = common::osrs::load_items(&cache)?;
         
@@ -32,7 +33,7 @@ mod osrs {
     }
     
     #[test]
-    fn load_logs_noted() -> rscache::Result<()> {
+    fn load_item_logs_noted() -> rscache::Result<()> {
         let cache = common::osrs::setup()?;
         let item_loader = common::osrs::load_items(&cache)?;
         
@@ -57,11 +58,12 @@ mod osrs {
     }
 }
 
+#[cfg(feature = "rs3")]
 mod rs3 {
     use super::common;
     
     #[test]
-    fn load_blue_partyhat() -> rscache::Result<()> {
+    fn load_item_blue_partyhat() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
         
@@ -75,7 +77,7 @@ mod rs3 {
     }
 
     #[test]
-    fn load_master_mining_cape() -> rscache::Result<()> {
+    fn load_item_master_mining_cape() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
 
@@ -91,7 +93,7 @@ mod rs3 {
     }
 
     #[test]
-    fn load_luminite_stone_spirit() -> rscache::Result<()> {
+    fn load_item_luminite_stone_spirit() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
 
@@ -106,7 +108,7 @@ mod rs3 {
     }
 
     #[test]
-    fn load_light_animica() -> rscache::Result<()> {
+    fn load_item_light_animica() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
 
@@ -121,7 +123,7 @@ mod rs3 {
     }
 
     #[test]
-    fn load_elder_rune_pickaxe_5() -> rscache::Result<()> {
+    fn load_item_elder_rune_pickaxe_5() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
 
@@ -137,7 +139,7 @@ mod rs3 {
     }
 
     #[test]
-    fn load_wergali_incense_sticks() -> rscache::Result<()> {
+    fn load_item_wergali_incense_sticks() -> rscache::Result<()> {
         let cache = common::rs3::setup()?;
         let item_loader = common::rs3::load_items(&cache)?;
 
